@@ -9,16 +9,10 @@
 * Author(s): Dan Halbert
 """
 
-from .keycode import Keycode
-
-try:
-    from .keyboard import Keyboard
-    from typing import Tuple
-except ImportError:
-    pass
+from .keyboard_layout_base import KeyboardLayoutBase
 
 
-class KeyboardLayoutUS:
+class KeyboardLayoutUS(KeyboardLayoutBase):
     """Map ASCII characters to appropriate keypresses on a standard US PC keyboard.
 
     Non-ASCII characters and most control characters will raise an exception.
@@ -37,7 +31,6 @@ class KeyboardLayoutUS:
     # if it's in a .mpy file, so it doesn't use up valuable RAM.
     #
     # \x00 entries have no keyboard key and so won't be sent.
-    SHIFT_FLAG = 0x80
     ASCII_TO_KEYCODE = (
         b"\x00"  # NUL
         b"\x00"  # SOH
@@ -169,75 +162,5 @@ class KeyboardLayoutUS:
         b"\x4c"  # DEL DELETE (called Forward Delete in usb.org document)
     )
 
-    def __init__(self, keyboard: Keyboard) -> None:
-        """Specify the layout for the given keyboard.
 
-        :param keyboard: a Keyboard object. Write characters to this keyboard when requested.
-
-        Example::
-
-            kbd = Keyboard(usb_hid.devices)
-            layout = KeyboardLayoutUS(kbd)
-        """
-
-        self.keyboard = keyboard
-
-    def write(self, string: str) -> None:
-        """Type the string by pressing and releasing keys on my keyboard.
-
-        :param string: A string of ASCII characters.
-        :raises ValueError: if any of the characters are not ASCII or have no keycode
-            (such as some control characters).
-
-        Example::
-
-            # Write abc followed by Enter to the keyboard
-            layout.write('abc\\n')
-        """
-        for char in string:
-            keycode = self._char_to_keycode(char)
-            # If this is a shifted char, clear the SHIFT flag and press the SHIFT key.
-            if keycode & self.SHIFT_FLAG:
-                keycode &= ~self.SHIFT_FLAG
-                self.keyboard.press(Keycode.SHIFT)
-            self.keyboard.press(keycode)
-            self.keyboard.release_all()
-
-    def keycodes(self, char: str) -> Tuple[int, ...]:
-        """Return a tuple of keycodes needed to type the given character.
-
-        :param char: A single ASCII character in a string.
-        :type char: str of length one.
-        :returns: tuple of Keycode keycodes.
-        :raises ValueError: if ``char`` is not ASCII or there is no keycode for it.
-
-        Examples::
-
-            # Returns (Keycode.TAB,)
-            keycodes('\t')
-            # Returns (Keycode.A,)
-            keycode('a')
-            # Returns (Keycode.SHIFT, Keycode.A)
-            keycode('A')
-            # Raises ValueError because it's a accented e and is not ASCII
-            keycode('é')
-        """
-        keycode = self._char_to_keycode(char)
-        if keycode & self.SHIFT_FLAG:
-            return (Keycode.SHIFT, keycode & ~self.SHIFT_FLAG)
-
-        return (keycode,)
-
-    def _char_to_keycode(self, char: str) -> int:
-        """Return the HID keycode for the given ASCII character, with the SHIFT_FLAG possibly set.
-
-        If the character requires pressing the Shift key, the SHIFT_FLAG bit is set.
-        You must clear this bit before passing the keycode in a USB report.
-        """
-        char_val = ord(char)
-        if char_val > 128:
-            raise ValueError("Not an ASCII character.")
-        keycode = self.ASCII_TO_KEYCODE[char_val]
-        if keycode == 0:
-            raise ValueError("No keycode available for character.")
-        return keycode
+KeyboardLayout = KeyboardLayoutUS
